@@ -306,7 +306,8 @@ def add_instance(session,
                  pg_version=None,
                  pg_version_summary=None,
                  pg_data=None,
-                 notify=False):
+                 notify=False,
+                 comment=None):
     try:
         instance = Instances(
             agent_address=unicode(new_agent_address),
@@ -327,6 +328,7 @@ def add_instance(session,
         if pg_data is not None:
             instance.pg_data = unicode(pg_data)
         instance.notify = bool(notify)
+        instance.comment = comment
         session.add(instance)
         session.flush()
         return instance
@@ -368,7 +370,8 @@ def update_instance(session,
                     pg_version=None,
                     pg_version_summary=None,
                     pg_data=None,
-                    notify=True):
+                    notify=True,
+                    comment=None):
     try:
         instance = session.query(Instances) \
             .filter_by(
@@ -392,6 +395,7 @@ def update_instance(session,
         else:
             instance.pg_port = None
         instance.notify = bool(notify)
+        instance.comment = comment
 
         for prop in ['agent_key', 'hostname', 'pg_version',
                      'pg_version_summary', 'pg_data']:
@@ -624,15 +628,12 @@ def delete_role_group_from_instance_group(session, role_group_name,
 
 
 def get_instances_by_role_name(session, role_name):
-    return session.query(Instances).options(
-        joinedload(Instances.groups), joinedload(Instances.plugins)).filter(
+    return session.query(Instances).filter(
             Instances.agent_address == InstanceGroups.agent_address,
             Instances.agent_port == InstanceGroups.agent_port,
             InstanceGroups.group_name ==
             AccessRoleInstance.instance_group_name,
             AccessRoleInstance.role_group_name == RoleGroups.group_name,
-            Plugins.agent_address == Instances.agent_address,
-            Plugins.agent_port == Instances.agent_port,
             RoleGroups.role_name == unicode(role_name)).order_by(
                 InstanceGroups.group_name, Instances.agent_address)
 
